@@ -167,4 +167,6 @@ const char *print_peer_gr_cmd(enum peer_gr_command pr_gr_cmd);
 const char *print_global_gr_mode(enum global_mode gl_mode);
 const char *print_global_gr_cmd(enum global_gr_command gl_gr_cmd);
 int bgp_peer_reg_with_nht(struct peer *peer);
+void bgp_gr_check_path_select(struct bgp *bgp, afi_t afi, safi_t safi);
+void bgp_gr_start_all_deferral_timers(struct bgp *bgp);
 #endif /* _QUAGGA_BGP_FSM_H */
