@@ -226,11 +226,28 @@ void igmp_source_reset_gmi(struct gm_group *group, struct gm_source *source)
 {
 	long group_membership_interval_msec;
 	struct interface *ifp;
+	struct pim_interface *pim_ifp;
+	struct prefix_sg sg = {
+		.family = AF_INET,
+		.prefixlen = IPV4_MAX_BITLEN,
+		.src.ipa_type = IPADDR_V4,
+		.src.ipaddr_v4 = source->source_addr,
+		.grp.ipa_type = IPADDR_V4,
+		.grp.ipaddr_v4 = group->group_addr,
+	};
 
 	ifp = group->interface;
+	pim_ifp = ifp->info;
 
 	group_membership_interval_msec = igmp_gmi_msec(group);
 
+	if (!pim_filter_match(&pim_ifp->gmp_filter, &sg, group->interface)) {
+		if (PIM_DEBUG_GM_TRACE)
+			zlog_debug("Timer for %pPSG on %s not refreshed due to route-map reject",
+				   &sg, ifp->name);
+		return;
+	}
+
 	if (PIM_DEBUG_GM_TRACE) {
 		char group_str[INET_ADDRSTRLEN];
 		char source_str[INET_ADDRSTRLEN];
@@ -425,10 +442,19 @@ struct gm_source *igmp_get_source_by_addr(struct gm_group *group,
 {
 	const struct pim_interface *pim_interface = group->interface->info;
 	struct gm_source *src;
+	struct prefix_sg sg = {
+		.family = AF_INET,
+		.prefixlen = IPV4_MAX_BITLEN,
+		.src.ipaddr_v4 = src_addr,
+		.grp.ipaddr_v4 = group->group_addr,
+	};
 
 	if (new)
 		*new = false;
 
+	if (!pim_filter_match(&pim_interface->gmp_filter, &sg, group->interface))
+		return NULL;
+
 	src = igmp_find_source_by_addr(group, src_addr);
 	if (src)
 		return src;
@@ -656,12 +682,25 @@ void igmpv3_report_isex(struct gm_sock *igmp, struct in_addr from,
 {
 	struct interface *ifp = igmp->interface;
 	struct gm_group *group;
+	struct pim_interface *pim_ifp = ifp->info;
+	struct prefix_sg sg = {
+		.family = AF_INET,
+		.prefixlen = IPV4_MAX_BITLEN,
+		.grp.ipa_type = IPADDR_V4,
+		.grp.ipaddr_v4 = group_addr,
+	};
 
 	on_trace(__func__, ifp, from, group_addr, num_sources, sources);
 
 	if (pim_is_group_filtered(ifp->info, &group_addr, NULL))
 		return;
 
+	if (!pim_filter_match(&pim_ifp->gmp_filter, &sg, igmp->interface)) {
+		if (PIM_DEBUG_GM_TRACE)
+			zlog_debug("Rejected ISEX %pPSG on %s due to route-map", &sg, ifp->name);
+		return;
+	}
+
 	/* non-existent group is created as INCLUDE {empty} */
 	group = igmp_add_group_by_addr(igmp, group_addr);
 	if (!group) {
@@ -950,9 +989,23 @@ void igmpv3_report_toex(struct gm_sock *igmp, struct in_addr from,
 {
 	struct interface *ifp = igmp->interface;
 	struct gm_group *group;
+	/* non-existent group is created as INCLUDE {empty} */
+	struct pim_interface *pim_ifp = ifp->info;
+	struct prefix_sg sg = {
+		.family = AF_INET,
+		.prefixlen = IPV4_MAX_BITLEN,
+		.grp.ipa_type = IPADDR_V4,
+		.grp.ipaddr_v4 = group_addr,
+	};
 
 	on_trace(__func__, ifp, from, group_addr, num_sources, sources);
 
+	if (!pim_filter_match(&pim_ifp->gmp_filter, &sg, igmp->interface)) {
+		if (PIM_DEBUG_GM_TRACE)
+			zlog_debug("Rejected TOEX %pPSG on %s due to route-map", &sg, ifp->name);
+		return;
+	}
+
 	/* non-existent group is created as INCLUDE {empty} */
 	group = igmp_add_group_by_addr(igmp, group_addr);
 	if (!group) {
@@ -1028,7 +1081,7 @@ static void group_retransmit_group(struct gm_group *group)
 	char query_buf[query_buf_size];
 
 	lmqc = pim_ifp->gm_last_member_query_count;
-	lmqi_msec = 100 * pim_ifp->gm_specific_query_max_response_time_dsec;
+	lmqi_msec = 100L * pim_ifp->gm_specific_query_max_response_time_dsec;
 	lmqt_msec = lmqc * lmqi_msec;
 
 	/*
@@ -1098,7 +1151,7 @@ static int group_retransmit_sources(struct gm_group *group,
 	pim_ifp = group->interface->info;
 
 	lmqc = pim_ifp->gm_last_member_query_count;
-	lmqi_msec = 100 * pim_ifp->gm_specific_query_max_response_time_dsec;
+	lmqi_msec = 100L * pim_ifp->gm_specific_query_max_response_time_dsec;
 	lmqt_msec = lmqc * lmqi_msec;
 
 	/* Scan all group sources */
@@ -1287,7 +1340,7 @@ static void group_retransmit_timer_on(struct gm_group *group)
 
 	pim_ifp = group->interface->info;
 
-	lmqi_msec = 100 * pim_ifp->gm_specific_query_max_response_time_dsec;
+	lmqi_msec = 100L * pim_ifp->gm_specific_query_max_response_time_dsec;
 
 	if (PIM_DEBUG_GM_TRACE) {
 		char group_str[INET_ADDRSTRLEN];
@@ -1356,7 +1409,7 @@ static void source_query_send_by_flag(struct gm_group *group,
 	pim_ifp = group->interface->info;
 
 	lmqc = pim_ifp->gm_last_member_query_count;
-	lmqi_msec = 100 * pim_ifp->gm_specific_query_max_response_time_dsec;
+	lmqi_msec = 100L * pim_ifp->gm_specific_query_max_response_time_dsec;
 	lmqt_msec = lmqc * lmqi_msec;
 
 	/*
@@ -1772,9 +1825,9 @@ void igmp_v3_recv_query(struct gm_sock *igmp, const char *from_str,
 		if (group_addr.s_addr == INADDR_ANY) {
 			/* this is a general query */
 			/* log that general query should have the s_flag set */
-			zlog_warn(
-				"General IGMP query v3 from %s on %s: Suppress Router-Side Processing flag is clear",
-				from_str, ifp->name);
+			if (PIM_DEBUG_GM_TRACE)
+				zlog_debug("General IGMP query v3 from %s on %s: Suppress Router-Side Processing flag is clear",
+					   from_str, ifp->name);
 		} else {
 			struct gm_group *group;
 
