@@ -474,6 +474,8 @@ int pim_config_write(struct vty *vty, int writes, struct interface *ifp,
 			vty_out(vty, " " PIM_AF_NAME " pim dm\n");
 		else if (pim_ifp->pim_mode == PIM_MODE_SPARSE_DENSE)
 			vty_out(vty, " " PIM_AF_NAME " pim sm-dm\n");
+		else if (pim_ifp->pim_mode == PIM_MODE_SSM)
+			vty_out(vty, " " PIM_AF_NAME " pim ssm\n");
 		else
 			vty_out(vty, " " PIM_AF_NAME " pim\n");
 		++writes;
