@@ -1,21 +1,6 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /* RIPng offset-list
  * Copyright (C) 2000 Kunihiro Ishiguro <kunihiro@zebra.org>
- *
- * This file is part of GNU Zebra.
- *
- * GNU Zebra is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * GNU Zebra is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /* RIPng support by Vincent Jardin <vincent.jardin@6wind.com>
@@ -98,9 +83,8 @@ int ripng_offset_list_apply_in(struct ripng *ripng, struct prefix_ipv6 *p,
 		alist = access_list_lookup(AFI_IP6,
 					   OFFSET_LIST_IN_NAME(offset));
 
-		if (alist
-		    && access_list_apply(alist, (struct prefix *)p)
-			       == FILTER_PERMIT) {
+		if (alist && access_list_apply(alist, (struct prefix *)p) ==
+				     FILTER_PERMIT) {
 			*metric += OFFSET_LIST_IN_METRIC(offset);
 			return 1;
 		}
@@ -112,9 +96,8 @@ int ripng_offset_list_apply_in(struct ripng *ripng, struct prefix_ipv6 *p,
 		alist = access_list_lookup(AFI_IP6,
 					   OFFSET_LIST_IN_NAME(offset));
 
-		if (alist
-		    && access_list_apply(alist, (struct prefix *)p)
-			       == FILTER_PERMIT) {
+		if (alist && access_list_apply(alist, (struct prefix *)p) ==
+				     FILTER_PERMIT) {
 			*metric += OFFSET_LIST_IN_METRIC(offset);
 			return 1;
 		}
@@ -136,9 +119,8 @@ int ripng_offset_list_apply_out(struct ripng *ripng, struct prefix_ipv6 *p,
 		alist = access_list_lookup(AFI_IP6,
 					   OFFSET_LIST_OUT_NAME(offset));
 
-		if (alist
-		    && access_list_apply(alist, (struct prefix *)p)
-			       == FILTER_PERMIT) {
+		if (alist && access_list_apply(alist, (struct prefix *)p) ==
+				     FILTER_PERMIT) {
 			*metric += OFFSET_LIST_OUT_METRIC(offset);
 			return 1;
 		}
@@ -151,9 +133,8 @@ int ripng_offset_list_apply_out(struct ripng *ripng, struct prefix_ipv6 *p,
 		alist = access_list_lookup(AFI_IP6,
 					   OFFSET_LIST_OUT_NAME(offset));
 
-		if (alist
-		    && access_list_apply(alist, (struct prefix *)p)
-			       == FILTER_PERMIT) {
+		if (alist && access_list_apply(alist, (struct prefix *)p) ==
+				     FILTER_PERMIT) {
 			*metric += OFFSET_LIST_OUT_METRIC(offset);
 			return 1;
 		}
