@@ -157,13 +157,12 @@ def teardown_module():
 #####################################################
 
 
-def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
+def test_dynamic_import_routes_between_two_tenant_vrf_p0(request):
     """
-    Verify that with multiple tenant VRFs, dynamic import works fine between
-    Tenant VRFs to default VRF.
+    Verify that dynamic import works fine between two different Tenant VRFs.
 
-    When next-hop IPs and prefixes are same across all VRFs.
-    When next-hop IPs and prefixes are different across all VRFs.
+    When next-hop IPs are same across all VRFs.
+    When next-hop IPs are different across all VRFs.
     """
 
     tgen = get_topogen()
@@ -237,157 +236,151 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                 tc_name, result
             )
 
-    step("Import all tenant vrfs(GREEN+BLUE+RED) in default vrf on R3")
+    step("Import from vrf GREEN+BLUE into vrf RED on R3")
 
-    for vrf_name in ["RED", "BLUE", "GREEN"]:
+    for vrf_name in ["BLUE", "GREEN"]:
         temp = {}
         for addr_type in ADDR_TYPES:
             temp.update({addr_type: {"unicast": {"import": {"vrf": vrf_name}}}})
 
-        redist_dict = {"r3": {"bgp": [{"local_as": 3, "address_family": temp}]}}
+        import_dict = {
+            "r3": {"bgp": [{"vrf": "RED", "local_as": 3, "address_family": temp}]}
+        }
 
-        result = create_router_bgp(tgen, topo, redist_dict)
+        result = create_router_bgp(tgen, topo, import_dict)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
             tc_name, result
         )
 
     step(
-        "Verify on R3 that it installs all the routes(imported from tenant "
-        "VRFs) in default vrf. Additionally, verify that R1 & R2 also "
-        "receive these routes from R3 and install in default vrf, next-hop "
-        "pointing to R3"
+        "Verify on R1, that it installs all the routes(local+imported) in "
+        "vrf RED's RIB/FIB and doesn't get confuse with next-hop attribute, "
+        "as all vrfs on R1 are using same IP address for next-hop"
     )
 
-    for vrf_name, network in zip(VRF_LIST, [NETWORK1_1, NETWORK2_1, NETWORK3_1]):
+    for addr_type in ADDR_TYPES:
+        static_routes = {
+            "r3": {
+                "static_routes": [
+                    {
+                        "network": [
+                            NETWORK1_1[addr_type],
+                            NETWORK2_1[addr_type],
+                            NETWORK3_1[addr_type],
+                        ],
+                        "next_hop": "blackhole",
+                        "vrf": "RED",
+                    }
+                ]
+            }
+        }
+
+        next_hop_1 = topo["routers"]["r3"]["links"]["r1-link1"][addr_type].split("/")[0]
+        result = verify_bgp_rib(
+            tgen, addr_type, "r1", static_routes, next_hop=next_hop_1
+        )
+        assert result is True, "Testcase {} : Failed \n Error {}".format(
+            tc_name, result
+        )
+
+        result = verify_rib(tgen, addr_type, "r1", static_routes, next_hop=next_hop_1)
+        assert result is True, "Testcase {} : Failed \n Error {}".format(
+            tc_name, result
+        )
+
+    step("Remove import vrf GREEN/BLUE/Both command from vrf RED's instance on" " R3")
+    for vrf_name in ["BLUE", "GREEN"]:
+        temp = {}
+        for addr_type in ADDR_TYPES:
+            temp.update(
+                {addr_type: {"unicast": {"import": {"vrf": vrf_name, "delete": True}}}}
+            )
+
+        import_dict = {
+            "r3": {"bgp": [{"vrf": "RED", "local_as": 3, "address_family": temp}]}
+        }
+
+        result = create_router_bgp(tgen, topo, import_dict)
+        assert result is True, "Testcase {} :Failed \n Error: {}".format(
+            tc_name, result
+        )
+
+    step("Verify that R1,R2 & R3 withdraw imported routes from vrf RED's RIB")
+    for dut in ["r1", "r2", "r3"]:
         for addr_type in ADDR_TYPES:
             static_routes = {
-                "r3": {
+                dut: {
                     "static_routes": [
                         {
-                            "network": [network[addr_type]],
+                            "network": [NETWORK2_1[addr_type], NETWORK3_1[addr_type]],
                             "next_hop": "blackhole",
+                            "vrf": "RED",
                         }
                     ]
                 }
             }
-
-            for dut in ["r2", "r1"]:
-                next_hop_val = topo["routers"]["r3"]["links"]["{}-link4".format(dut)][
-                    addr_type
-                ].split("/")[0]
-
-                result = verify_bgp_rib(
-                    tgen, addr_type, dut, static_routes, next_hop=next_hop_val
+            result = verify_bgp_rib(tgen, addr_type, dut, static_routes, expected=False)
+            assert result is not True, (
+                "Testcase {} : Failed \nError {}\n"
+                "Routes {} still in BGP table".format(
+                    tc_name, result, static_routes[dut]["static_routes"][0]["network"]
                 )
-                assert result is True, "Testcase {} : Failed \n Error {}".format(
-                    tc_name, result
-                )
-
-                result = verify_rib(
-                    tgen, addr_type, dut, static_routes, next_hop=next_hop_val
-                )
-                assert result is True, "Testcase {} : Failed \n Error {}".format(
-                    tc_name, result
-                )
-
-            result = verify_bgp_rib(tgen, addr_type, "r3", static_routes)
-            assert result is True, "Testcase {} : Failed \n Error {}".format(
-                tc_name, result
             )
 
-            result = verify_rib(tgen, addr_type, "r3", static_routes)
-            assert result is True, "Testcase {} : Failed \n Error {}".format(
-                tc_name, result
+            result = verify_rib(tgen, addr_type, dut, static_routes, expected=False)
+            assert result is not True, (
+                "Testcase {} : Failed \nError {}\n"
+                "Routes {} still in Route table".format(
+                    tc_name, result, static_routes[dut]["static_routes"][0]["network"]
+                )
             )
 
-    for action, value, status in zip(
-        ["Remove", "Add"], [True, False], ["withdraw", "re-install"]
-    ):
-        step(
-            "{} import vrf GREEN/BLUE/RED/all command from default vrf "
-            "instance on R3".format(action)
+    step("Add import vrf GREEN/BLUE/Both command from vrf RED's instance on " "R3")
+    for vrf_name in ["BLUE", "GREEN"]:
+        temp = {}
+        for addr_type in ADDR_TYPES:
+            temp.update({addr_type: {"unicast": {"import": {"vrf": vrf_name}}}})
+
+        import_dict = {
+            "r3": {"bgp": [{"vrf": "RED", "local_as": 3, "address_family": temp}]}
+        }
+
+        result = create_router_bgp(tgen, topo, import_dict)
+        assert result is True, "Testcase {} :Failed \n Error: {}".format(
+            tc_name, result
         )
-        for vrf_name in ["RED", "BLUE", "GREEN"]:
-            temp = {}
-            for addr_type in ADDR_TYPES:
-                temp.update(
-                    {
-                        addr_type: {
-                            "unicast": {"import": {"vrf": vrf_name, "delete": value}}
+
+    for dut in ["r1", "r2", "r3"]:
+        step("Verify that {} reinstall imported routes from vrf RED's RIB".format(dut))
+        for addr_type in ADDR_TYPES:
+            static_routes = {
+                dut: {
+                    "static_routes": [
+                        {
+                            "network": [NETWORK2_1[addr_type], NETWORK3_1[addr_type]],
+                            "next_hop": "blackhole",
+                            "vrf": "RED",
                         }
-                    }
-                )
-
-            import_dict = {"r3": {"bgp": [{"local_as": 3, "address_family": temp}]}}
-
-            result = create_router_bgp(tgen, topo, import_dict)
-            assert result is True, "Testcase {} :Failed \n Error: {}".format(
+                    ]
+                }
+            }
+            result = verify_bgp_rib(tgen, addr_type, dut, static_routes)
+            assert result is True, "Testcase {} : Failed \n Error {}".format(
                 tc_name, result
             )
 
-        step(
-            "Verify that R1,R2 & R3 {} imported routes from GREEN/BLUE/RED/all"
-            " in default vrf's RIB".format(status)
-        )
-        for dut in ["r1", "r2", "r3"]:
-            for addr_type in ADDR_TYPES:
-                static_routes = {
-                    dut: {
-                        "static_routes": [
-                            {
-                                "network": [
-                                    NETWORK1_1[addr_type],
-                                    NETWORK2_1[addr_type],
-                                    NETWORK3_1[addr_type],
-                                ],
-                                "next_hop": "blackhole",
-                            }
-                        ]
-                    }
-                }
-
-                if value:
-                    result = verify_bgp_rib(
-                        tgen, addr_type, dut, static_routes, expected=False
-                    )
-                    assert result is not True, (
-                        "Testcase {} : Failed \nError {}\n"
-                        "Routes {} still in BGP table".format(
-                            tc_name,
-                            result,
-                            static_routes[dut]["static_routes"][0]["network"],
-                        )
-                    )
-
-                    result = verify_rib(
-                        tgen, addr_type, dut, static_routes, expected=False
-                    )
-                    assert result is not True, (
-                        "Testcase {} : Failed \nError {}\n"
-                        "Routes {} still in BGP table".format(
-                            tc_name,
-                            result,
-                            static_routes[dut]["static_routes"][0]["network"],
-                        )
-                    )
-                else:
-                    result = verify_bgp_rib(tgen, addr_type, dut, static_routes)
-                    assert result is True, "Testcase {} : Failed \n Error {}".format(
-                        tc_name, result
-                    )
-
-                    result = verify_rib(tgen, addr_type, dut, static_routes)
-                    assert result is True, "Testcase {} : Failed \n Error {}".format(
-                        tc_name, result
-                    )
+            result = verify_rib(tgen, addr_type, dut, static_routes)
+            assert result is True, "Testcase {} : Failed \n Error {}".format(
+                tc_name, result
+            )
 
     for action, value in zip(["Shut", "No shut"], [True, False]):
         step(
-            "{} the neighborship between R1-R3 and R1-R2 for vrf RED, GREEN "
-            "and BLUE".format(action)
+            "{} the neighborship between R1-R3 and R1-R2 for vrf GREEN, BLUE "
+            "and default".format(action)
         )
         bgp_disable = {"r3": {"bgp": []}}
-        for vrf_name in ["RED", "GREEN", "BLUE"]:
+        for vrf_name in ["GREEN", "BLUE", "default"]:
             temp = {}
             for addr_type in ADDR_TYPES:
                 temp.update(
@@ -396,10 +389,10 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                             "unicast": {
                                 "neighbor": {
                                     "r1": {
-                                        "dest_link": {"r3-link4": {"shutdown": value}}
+                                        "dest_link": {"r3-link1": {"shutdown": value}}
                                     },
                                     "r2": {
-                                        "dest_link": {"r3-link4": {"shutdown": value}}
+                                        "dest_link": {"r3-link1": {"shutdown": value}}
                                     },
                                 }
                             }
@@ -415,23 +408,20 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
             tc_name, result
         )
 
-        step(
-            "Verify that when peering is shutdown for tenant vrfs, it "
-            "doesn't impact the RIB/FIB of default vrf on router R1 and R2"
-        )
-        for dut in ["r1", "r2"]:
-            step("Verify RIB/FIB for default vrf on {}".format(dut))
+        step("Verify RIB/FIB of vrf RED will be unchanged on all 3 routers")
+        for dut in ["r1", "r2", "r3"]:
+            step("Verify RIB/FIB for vrf RED on {}".format(dut))
             for addr_type in ADDR_TYPES:
                 static_routes = {
                     dut: {
                         "static_routes": [
                             {
                                 "network": [
-                                    NETWORK1_1[addr_type],
                                     NETWORK2_1[addr_type],
                                     NETWORK3_1[addr_type],
                                 ],
                                 "next_hop": "blackhole",
+                                "vrf": "RED",
                             }
                         ]
                     }
@@ -449,9 +439,7 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
     for action, value, status in zip(
         ["Shut", "No shut"], [True, False], ["Withdraw", "Reinstall"]
     ):
-        step(
-            "{} the neighborship between R1-R3 and R2-R3 for default vrf".format(action)
-        )
+        step("{} the neighborship between R1-R3 and R1-R2 for vrf RED".format(action))
         temp = {}
         for addr_type in ADDR_TYPES:
             temp.update(
@@ -459,37 +447,39 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                     addr_type: {
                         "unicast": {
                             "neighbor": {
-                                "r1": {"dest_link": {"r3-link4": {"shutdown": value}}},
-                                "r2": {"dest_link": {"r3-link4": {"shutdown": value}}},
+                                "r1": {"dest_link": {"r3-link1": {"shutdown": value}}},
+                                "r2": {"dest_link": {"r3-link1": {"shutdown": value}}},
                             }
                         }
                     }
                 }
             )
 
-        bgp_disable = {"r3": {"bgp": [{"local_as": 3, "address_family": temp}]}}
+        bgp_disable = {
+            "r3": {"bgp": [{"vrf": "RED", "local_as": 3, "address_family": temp}]}
+        }
         result = create_router_bgp(tgen, topo, bgp_disable)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
             tc_name, result
         )
 
         step(
-            "Verify that R1 and R2 {} all the routes from default vrf's RIB"
-            " and FIB".format(status)
+            "Verify that R1 and R2 {} all the routes from RED vrf's RIB and"
+            " FIB".format(status)
         )
         for dut in ["r1", "r2"]:
-            step("Verify RIB/FIB for default vrf on {}".format(dut))
+            step("Verify RIB/FIB for vrf RED on {}".format(dut))
             for addr_type in ADDR_TYPES:
                 static_routes = {
                     dut: {
                         "static_routes": [
                             {
                                 "network": [
-                                    NETWORK1_1[addr_type],
                                     NETWORK2_1[addr_type],
                                     NETWORK3_1[addr_type],
                                 ],
                                 "next_hop": "blackhole",
+                                "vrf": "RED",
                             }
                         ]
                     }
@@ -512,7 +502,7 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                         tgen, addr_type, dut, static_routes, expected=False
                     )
                     assert result is not True, (
-                        "Testcase {} : Failed Error {}"
+                        "Testcase {} : Failed \nError {}\n"
                         "Routes {} still in Route table".format(
                             tc_name,
                             result,
@@ -531,14 +521,16 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                     )
 
     step("Remove import command from router R3 and configure the same on R2")
-    temp = {}
-    for vrf_name in VRF_LIST:
+    for vrf_name in ["BLUE", "GREEN"]:
+        temp = {}
         for addr_type in ADDR_TYPES:
             temp.update(
                 {addr_type: {"unicast": {"import": {"vrf": vrf_name, "delete": True}}}}
             )
 
-        import_dict = {"r3": {"bgp": [{"local_as": 3, "address_family": temp}]}}
+        import_dict = {
+            "r3": {"bgp": [{"vrf": "RED", "local_as": 3, "address_family": temp}]}
+        }
 
         result = create_router_bgp(tgen, topo, import_dict)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
@@ -547,22 +539,19 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
 
     step(
         "Verify that once import commands are removed from R3, all imported "
-        "routes are withdrawn from RIB/FIB of default vrf on R1/R2/R3"
+        "routes are withdrawn from RIB/FIB of vrf RED on R1/R2/R3"
     )
 
     for dut in ["r1", "r2", "r3"]:
-        step("Verify RIB/FIB for default vrf on {}".format(dut))
+        step("Verify RIB/FIB for vrf RED on {}".format(dut))
         for addr_type in ADDR_TYPES:
             static_routes = {
                 dut: {
                     "static_routes": [
                         {
-                            "network": [
-                                NETWORK1_1[addr_type],
-                                NETWORK2_1[addr_type],
-                                NETWORK3_1[addr_type],
-                            ],
+                            "network": [NETWORK2_1[addr_type], NETWORK3_1[addr_type]],
                             "next_hop": "blackhole",
+                            "vrf": "RED",
                         }
                     ]
                 }
@@ -576,12 +565,18 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
             )
 
             result = verify_rib(tgen, addr_type, dut, static_routes, expected=False)
-            assert result is not True, "Testcase {} : Failed \n Error {}".format(
-                tc_name, result
+            assert (
+                result is not True
+            ), "Testcase {} : Failed Error {}" "Routes {} still in Route table".format(
+                tc_name, result, static_routes[dut]["static_routes"][0]["network"]
             )
 
+    step(
+        "Configure static routes on R2 for each vrf and redistribute in "
+        "respective BGP instance"
+    )
     for vrf_name, network in zip(VRF_LIST, [NETWORK1_1, NETWORK2_1, NETWORK3_1]):
-        step("Configure static route for VRF : {} on r2".format(vrf_name))
+        step("Configure static route for VRF : {}".format(vrf_name))
         for addr_type in ADDR_TYPES:
             static_routes = {
                 "r2": {
@@ -638,12 +633,14 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
             tc_name, result
         )
 
-    for vrf_name in ["RED", "BLUE", "GREEN"]:
+    for vrf_name in ["BLUE", "GREEN"]:
         temp = {}
         for addr_type in ADDR_TYPES:
             temp.update({addr_type: {"unicast": {"import": {"vrf": vrf_name}}}})
 
-        import_dict = {"r2": {"bgp": [{"local_as": 2, "address_family": temp}]}}
+        import_dict = {
+            "r2": {"bgp": [{"vrf": "RED", "local_as": 2, "address_family": temp}]}
+        }
 
         result = create_router_bgp(tgen, topo, import_dict)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
@@ -652,7 +649,7 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
 
     step(
         "Verify after import commands are re-configured on R2's vrf RED, all "
-        "those routes are installed again in default vrf of R1,R2,R3"
+        "those routes are installed again in vrf RED of R1,R2,R3"
     )
     for dut in ["r1", "r2", "r3"]:
         step("Verify RIB/FIB for vrf RED on {}".format(dut))
@@ -667,6 +664,7 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                                 NETWORK3_1[addr_type],
                             ],
                             "next_hop": "blackhole",
+                            "vrf": "RED",
                         }
                     ]
                 }
@@ -681,37 +679,35 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                 tc_name, result
             )
 
-    step("Remove import vrf RED/GREEN/BLUE/all one by one from default vrf" " on R2")
-    for vrf_name in ["RED", "BLUE", "GREEN"]:
+    step(
+        "Remove/add import vrf GREEN/BLUE/both command from vrf RED's " "instance on R2"
+    )
+    for vrf_name in ["BLUE", "GREEN"]:
         temp = {}
         for addr_type in ADDR_TYPES:
             temp.update(
                 {addr_type: {"unicast": {"import": {"vrf": vrf_name, "delete": True}}}}
             )
 
-        import_dict = {"r2": {"bgp": [{"local_as": 2, "address_family": temp}]}}
+        redist_dict = {
+            "r2": {"bgp": [{"vrf": "RED", "local_as": 2, "address_family": temp}]}
+        }
 
-        result = create_router_bgp(tgen, topo, import_dict)
+        result = create_router_bgp(tgen, topo, redist_dict)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
             tc_name, result
         )
 
-    step(
-        "Verify that R1, R2 and R3 withdraws imported routes from default "
-        "vrf's RIB and FIB "
-    )
+    step("Verify that R1,R2 & R3 withdraw imported routes from vrf RED's RIB")
     for dut in ["r1", "r2", "r3"]:
         for addr_type in ADDR_TYPES:
             static_routes = {
                 dut: {
                     "static_routes": [
                         {
-                            "network": [
-                                NETWORK1_1[addr_type],
-                                NETWORK2_1[addr_type],
-                                NETWORK3_1[addr_type],
-                            ],
+                            "network": [NETWORK2_1[addr_type], NETWORK3_1[addr_type]],
                             "next_hop": "blackhole",
+                            "vrf": "RED",
                         }
                     ]
                 }
@@ -725,19 +721,23 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
             )
 
             result = verify_rib(tgen, addr_type, dut, static_routes, expected=False)
-            assert result is not True, "Testcase {} : Failed \n Error {}".format(
-                tc_name, result
+            assert (
+                result is not True
+            ), "Testcase {} : Failed Error {}" "Routes {} still in Route table".format(
+                tc_name, result, static_routes[dut]["static_routes"][0]["network"]
             )
 
-    step("Add import vrf RED/GREEN/BLUE/all one by one from default vrf on R2")
-    for vrf_name in ["RED", "BLUE", "GREEN"]:
+    step("Add import vrf GREEN/BLUE/Both command from vrf RED's instance on " "R2")
+    for vrf_name in ["BLUE", "GREEN"]:
         temp = {}
         for addr_type in ADDR_TYPES:
             temp.update({addr_type: {"unicast": {"import": {"vrf": vrf_name}}}})
 
-        import_dict = {"r2": {"bgp": [{"local_as": 2, "address_family": temp}]}}
+        redist_dict = {
+            "r2": {"bgp": [{"vrf": "RED", "local_as": 2, "address_family": temp}]}
+        }
 
-        result = create_router_bgp(tgen, topo, import_dict)
+        result = create_router_bgp(tgen, topo, redist_dict)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
             tc_name, result
         )
@@ -749,12 +749,9 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                 dut: {
                     "static_routes": [
                         {
-                            "network": [
-                                NETWORK1_1[addr_type],
-                                NETWORK2_1[addr_type],
-                                NETWORK3_1[addr_type],
-                            ],
+                            "network": [NETWORK2_1[addr_type], NETWORK3_1[addr_type]],
                             "next_hop": "blackhole",
+                            "vrf": "RED",
                         }
                     ]
                 }
@@ -771,12 +768,12 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
 
     for action, value in zip(["Shut", "No shut"], [True, False]):
         step(
-            "{} the neighborship between R2-R3 for vrf GREEN, BLUE and RED".format(
+            "{} the neighborship between R2-R3 for vrf GREEN, BLUE and default".format(
                 action
             )
         )
         bgp_disable = {"r2": {"bgp": []}}
-        for vrf_name in ["GREEN", "BLUE", "RED"]:
+        for vrf_name in ["GREEN", "BLUE", "default"]:
             temp = {}
             for addr_type in ADDR_TYPES:
                 temp.update(
@@ -785,7 +782,7 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                             "unicast": {
                                 "neighbor": {
                                     "r3": {
-                                        "dest_link": {"r2-link4": {"shutdown": value}}
+                                        "dest_link": {"r2-link1": {"shutdown": value}}
                                     }
                                 }
                             }
@@ -810,16 +807,15 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                         "static_routes": [
                             {
                                 "network": [
-                                    NETWORK1_1[addr_type],
                                     NETWORK2_1[addr_type],
                                     NETWORK3_1[addr_type],
                                 ],
                                 "next_hop": "blackhole",
+                                "vrf": "RED",
                             }
                         ]
                     }
                 }
-
                 result = verify_bgp_rib(tgen, addr_type, dut, static_routes)
                 assert result is True, "Testcase {} : Failed \n Error {}".format(
                     tc_name, result
@@ -833,7 +829,7 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
     for action, value, status in zip(
         ["Shut", "No shut"], [True, False], ["Withdraw", "Reinstall"]
     ):
-        step("{} the neighborship between R2-R3 for default vrf".format(action))
+        step("{} the neighborship between R2-R3 for vrf RED".format(action))
         temp = {}
         for addr_type in ADDR_TYPES:
             temp.update(
@@ -841,36 +837,38 @@ def test_dynamic_import_routes_between_tenant_to_default_vrf_p0(request):
                     addr_type: {
                         "unicast": {
                             "neighbor": {
-                                "r3": {"dest_link": {"r2-link4": {"shutdown": value}}}
+                                "r2": {"dest_link": {"r3-link1": {"shutdown": value}}}
                             }
                         }
                     }
                 }
             )
 
-        bgp_disable = {"r2": {"bgp": [{"local_as": 2, "address_family": temp}]}}
+        bgp_disable = {
+            "r3": {"bgp": [{"vrf": "RED", "local_as": 3, "address_family": temp}]}
+        }
         result = create_router_bgp(tgen, topo, bgp_disable)
         assert result is True, "Testcase {} :Failed \n Error: {}".format(
             tc_name, result
         )
 
         step(
-            "Verify that R1 and R2 {} all the routes from default vrfs RIB and"
+            "Verify that R1 and R2 {} all the routes from RED vrf's RIB and"
             " FIB".format(status)
         )
         for dut in ["r1", "r3"]:
-            step("Verify RIB/FIB for default vrf on {}".format(dut))
+            step("Verify RIB/FIB for vrf RED on {}".format(dut))
             for addr_type in ADDR_TYPES:
                 static_routes = {
                     dut: {
                         "static_routes": [
                             {
                                 "network": [
-                                    NETWORK1_1[addr_type],
                                     NETWORK2_1[addr_type],
                                     NETWORK3_1[addr_type],
                                 ],
                                 "next_hop": "blackhole",
+                                "vrf": "RED",
                             }
                         ]
                     }
