@@ -25,8 +25,6 @@ import sys
 import time
 import pytest
 import platform
-import functools
-from lib import topotest
 from copy import deepcopy
 
 
@@ -2051,18 +2049,6 @@ def test_bgp_attributes_for_evpn_address_family_p1(request, attribute):
             tc_name, result
         )
 
-        expected = {"numL3Vnis": 0}
-        test_func = functools.partial(
-            topotest.router_json_cmp,
-            tgen.gears["d1"],
-            "show bgp l2vpn evpn vni json",
-            expected,
-        )
-        _, result = topotest.run_and_expect(test_func, None, count=5, wait=3)
-        assert result is None, "Testcase {} :Failed \n Error: {}".format(
-            tc_name, result
-        )
-
         input_dict_2 = {}
         for dut in ["d1"]:
             temp = {dut: {"bgp": []}}
