@@ -1,36 +1,25 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Kernel routing table read by sysctl function.
  * Copyright (C) 1997, 98 Kunihiro Ishiguro
- *
- * This file is part of GNU Zebra.
- *
- * GNU Zebra is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * GNU Zebra is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <zebra.h>
 
-#if !defined(GNU_LINUX) && !defined(SUNOS_5)
+#include <net/route.h>
+
+#if !defined(GNU_LINUX)
+
+#include <sys/sysctl.h>
 
 #include "memory.h"
-#include "zebra_memory.h"
 #include "log.h"
 #include "vrf.h"
 
 #include "zebra/rt.h"
 #include "zebra/kernel_socket.h"
 #include "zebra/zebra_pbr.h"
+#include "zebra/zebra_tc.h"
 #include "zebra/zebra_errors.h"
 
 /* Kernel routing table read up by sysctl function. */
@@ -84,12 +73,17 @@ void macfdb_read(struct zebra_ns *zns)
 }
 
 void macfdb_read_for_bridge(struct zebra_ns *zns, struct interface *ifp,
-			    struct interface *br_if)
+			    struct interface *br_if, vlanid_t vid)
+{
+}
+
+void macfdb_read_mcast_entry_for_vni(struct zebra_ns *zns,
+				     struct interface *ifp, vni_t vni)
 {
 }
 
 void macfdb_read_specific_mac(struct zebra_ns *zns, struct interface *br_if,
-			      struct ethaddr *mac, vlanid_t vid)
+			      const struct ethaddr *mac, vlanid_t vid)
 {
 }
 
@@ -101,7 +95,7 @@ void neigh_read_for_vlan(struct zebra_ns *zns, struct interface *vlan_if)
 {
 }
 
-void neigh_read_specific_ip(struct ipaddr *ip, struct interface *vlan_if)
+void neigh_read_specific_ip(const struct ipaddr *ip, struct interface *vlan_if)
 {
 }
 
@@ -109,4 +103,12 @@ void kernel_read_pbr_rules(struct zebra_ns *zns)
 {
 }
 
-#endif /* !defined(GNU_LINUX) && !defined(SUNOS_5) */
+void kernel_read_tc_qdisc(struct zebra_ns *zns)
+{
+}
+
+void vlan_read(struct zebra_ns *zns)
+{
+}
+
+#endif /* !defined(GNU_LINUX) */
